@@ -46,7 +46,7 @@ ssllrm <- function(formula,response,type=NULL,data=list(),weights,
         ind.wk <- c(ind.wk,any(facs[ynames,lab]))
     term$labels <- term.labels[ind.wk]
     ## Generate quadrature
-    qd.pt <- data.frame(levels(mf[,ynames[1]]))
+    qd.pt <- data.frame(levels(mf[,ynames[1]]),stringsAsFactors=TRUE)
     if (is.null(cnt)) wt.wk <- table(mf[,ynames[1]])
     else {
         wt.wk <- NULL
@@ -57,7 +57,7 @@ ssllrm <- function(formula,response,type=NULL,data=list(),weights,
     if (length(ynames)>1) {
         for (ylab in ynames[-1]) {
             wk <- expand.grid(levels(mf[,ylab]),1:dim(qd.pt)[1])
-            qd.pt <- data.frame(qd.pt[wk[,2],],wk[,1])
+            qd.pt <- data.frame(qd.pt[wk[,2],],wk[,1],stringsAsFactors=TRUE)
             if (is.null(cnt)) wt.wk <- table(mf[,ylab])
             else {
                 wt.wk <- NULL
@@ -73,7 +73,7 @@ ssllrm <- function(formula,response,type=NULL,data=list(),weights,
     ## obtain unique covariate observations
     xx <- mf[,xnames,drop=FALSE]
     if (!is.null(random)) {
-        if (class(random)=="formula") random <- mkran(random,data)
+        if (inherits(random,"formula")) random <- mkran(random,data)
         xx <- cbind(xx,random$z)
     }
     xx <- apply(xx,1,function(x)paste(x,collapse="\r"))
@@ -248,7 +248,7 @@ mspllrm <- function(s,r,id.basis,cnt,qd.s,qd.r,xx.wt,qd.wt,
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk,s))), as.integer(nobs),
-                        as.integer(cntsum), as.double(cnt),
+                        as.double(cntsum), as.double(cnt),
                         as.double(qd.r.wk), as.integer(nqd), as.integer(nx),
                         as.double(xx.wt), as.double(qd.wt),
                         as.double(prec), as.integer(maxiter),
@@ -309,7 +309,7 @@ mspllrm <- function(s,r,id.basis,cnt,qd.s,qd.r,xx.wt,qd.wt,
                         cd=as.double(cd), as.integer(nn),
                         as.double(q.wk0), as.integer(nxiz),
                         as.double(t(cbind(r.wk0,s))), as.integer(nobs),
-                        as.integer(cntsum), as.double(cnt),
+                        as.double(cntsum), as.double(cnt),
                         as.double(qd.r.wk0), as.integer(nqd), as.integer(nx),
                         as.double(xx.wt), as.double(qd.wt),
                         as.double(prec), as.integer(maxiter),
