@@ -27,7 +27,8 @@
 static double quafo;                         /* cubature result             */
 static double x[maxdim];                     /* function argument           */ 
 static double xnu[fn][uniw],dnu[fn][uniw];   /* Delta-parameter             */
-static double fsumme, wsum, wprod, summe;    /* working var's               */
+static double fsumme, summe;    /* working var's               */
+/* static double fsumme, wsum, wprod, summe;     working var's               */
 static int d, q;                             /* cubature formula parameter  */
 static int n[fn], ninv[fn], sw[gesfn];       /* working var's               */
        int count, wcount;       /* counter of f-calls and coefficient calls */
@@ -39,7 +40,7 @@ static int anzw[uniw],
   lookind[fn][uniw], 
   invlook[fn][uniw], maxind;          /* tree parameter              */  
 
-static int wind[maxdim];      /* Parameter for slow coefficient calculation */
+/* static int wind[maxdim];       Parameter for slow coefficient calculation */
 
 static double (*f)(int, double x[]);         /* integrand (global)          */
 static void formula(int,int);                /* sub-formula "between  
@@ -55,7 +56,7 @@ static void eval1(int, double *pt, double *wt);
 static void fsum1(int, double *pt, double *wt);
 /* get pt and wt from formula1, eval1, fsum1 -- C. Gu */
 
-static void init();                          /* initialization              */
+static void init(void);                          /* initialization              */
 
 static double calccoeff(int);                /* coefficient calculator      */
 /* static double calccoeff2(int,int); */      /* coefficient calculator (slow)   */
@@ -76,7 +77,7 @@ struct tnode {
 
 static struct tnode *root;
  
-static double coeff();                   /* tree manager            */
+static double coeff(void);                   /* tree manager            */
 
 static struct tnode *talloc(void);       /* node generator          */
 static void frei(struct tnode *p);       /* tree eraser             */
@@ -224,7 +225,7 @@ void eval1(int k, double *pt, double *wt)
 /********************** Coefficients ************************/
 /* Tree-functions: */
 
-double coeff ( )
+double coeff (void)
      /* looks for existing coefficient or calls its
 	calculation                                         */
 {
@@ -474,7 +475,7 @@ void fsum1 (int k, double *pt, double *wt)
 
 /* initialisation  */
 
-void init()
+void init(void)
 { 
   int i, j, formfakt, maxform;
   int nj[fn]  ={1,3,7,15,31,63}; /* # nodes of different basic formulae */
